@@ -1,20 +1,28 @@
 import hashlib
-import itertools
-from io import BytesIO
 
 import requests
 
 from .DataLoader import DataLoader
+from .Dataset import Dataset
 from .saving.saving import save_data
 from .web.urls import TOKEN_URL, HASH_URL, UPLOAD_DATA_URL
-from .Dataset import Dataset
+
+VERBOSITY = 1
+MIN_VERBOSITY = 1
+MID_VERBOSITY = 2
+FULL_VERBOSITY = 3
+
 
 _token = ""
 
 
-def api(token_):
+def api(token_, verbosity):
     global _token
+    global VERBOSITY
     _token = token_
+    VERBOSITY = verbosity
+    if VERBOSITY != MIN_VERBOSITY:
+        print("Verbosity level set to {}".format(VERBOSITY))
     params = {"token": _token}
     response = requests.get(TOKEN_URL, params=params)
     if response.status_code == 200:
@@ -29,6 +37,10 @@ def getToken():
     return _token
 
 
+def getVerbosity():
+    return VERBOSITY
+
+
 def getResponse(response):
     try:
         return response.json()
@@ -36,6 +48,18 @@ def getResponse(response):
         raise ConnectionError("Invalid response received. Error: {}".format(response.text))
 
 
+def add_kwargs_to_params(params, **kwargs):
+    params = {**params, **kwargs}
+    return params
+
+
+def checkModel(model):
+    from .Task import Task
+    from .Model import Model
+    if not isinstance(model, Task) and not isinstance(model, str) and not isinstance(model, Model):
+        raise ValueError("Model is not a valid format. Please make sure you've compiled it first.")
+
+
 def checkData(data):
     if isinstance(data, (str, dict)):
         return data
@@ -60,18 +84,21 @@ def sliceData(data):
 
 def uploadDataLoader(dl):
     length = len(dl)
-    print("Hashing data locally...")
+    if VERBOSITY >= MID_VERBOSITY:
+        print("Hashing data locally...")
     hash, size = dl.hash()
     params = {"token": getToken(), "hash": hash, "collection": 1, "chunked": True, "is_last": False, "size": size}
     print("Checking if data is on servers...")
     response = requests.get(HASH_URL, params=params)
     if response.status_code == 200:
-        print("Data already uploaded. Will not reupload.")
+        if VERBOSITY >= MID_VERBOSITY:
+            print("Data already uploaded. Will not reupload.")
         return response
     print("Data not on servers. Starting to upload. Total size of data is {} bytes".format(size))
     print("{} chunks to upload...".format(length))
     for i, data_part in enumerate(dl.numpy()):
-        print("Uploading chunk {} out of {}...".format(i + 1, length))
+        if VERBOSITY >= MID_VERBOSITY:
+            print("Uploading chunk {} out of {}...".format(i + 1, length))
         file = save_data(data_part)
         files = {'file': file}
         if i == length - 1:
@@ -91,12 +118,14 @@ def read_in_chunks(file_object, chunk_size=1024):
 
 
 def uploadData(data):
-    print("Saving data locally...")
+    if VERBOSITY >= FULL_VERBOSITY:
+        print("Saving data locally...")
     if isinstance(data, str):
         file = open(data, "rb")
     else:
         file = save_data(data)
-    print("Hashing...")
+    if VERBOSITY >= FULL_VERBOSITY:
+        print("Hashing...")
     hash = hashlib.md5()
     size = 0
     for piece in read_in_chunks(file):
@@ -107,7 +136,8 @@ def uploadData(data):
     params = {"token": getToken(), "hash": hash, "collection": 1}
     response = requests.get(HASH_URL, params=params)
     if response.status_code == 200:
-        print("Data already on servers. Returning result...")
+        if VERBOSITY >= MID_VERBOSITY:
+            print("Data already on servers. Returning result...")
         file.close()
         return response
     print("Data not found on servers. Total size of data is {} bytes. Uploading now...".format(size))
