@@ -82,9 +82,12 @@ def hash_model(model, library):
         for param in sorted(model.collect_params().items()):
             hash.update(utf_str(param[1].data()))
     elif library == "TF":
-        hash.update(utf_str(model.to_json()))
-        for param in model.trainable_variables:
-            hash.update(utf_str(param))
+        try:
+            hash.update(utf_str(model.to_json()))
+            for param in model.trainable_variables:
+                hash.update(utf_str(param))
+        except NotImplementedError:
+            return ""
     else:
         raise ValueError("Cannot hash... Model type: {} not defined.".format(library))
     return hash.hexdigest()
