@@ -1,13 +1,13 @@
 from . import core, optim, loss
 
 
-def api(token):
+def api(token, verbosity=1):
     """Use this function to get access to the API, providing your token. All subsequents API calls will use this token.
 
         :param token: Token from dashboard
         :type token: str
     """
-    core.api(token)
+    core.api(token, verbosity)
 
 
 def compile(model, input_shape=[], library="", model_label="", asynchronous=False):
@@ -33,7 +33,7 @@ def compile(model, input_shape=[], library="", model_label="", asynchronous=Fals
     return core.compile(model, input_shape, library, model_label, asynchronous)
 
 
-def predict(model, data, asynchronous=False, callback=None):
+def predict(model, data, asynchronous=False, callback=None, **kwargs):
     """Perform a predict using a model. Default behaviour is synchronous.
 
         :param model: Model used to predict
@@ -45,10 +45,10 @@ def predict(model, data, asynchronous=False, callback=None):
         :param callback: runs a callback function on results (asynchronous)
         :type callback: function
     """
-    return core.predict(model, data, asynchronous, callback)
+    return core.predict(model, data, asynchronous, callback, **kwargs)
 
 
-def train(model, train_data, val_data, batch_size=32, epochs=1, optim=optim.SGD(), loss=loss.SparseCrossEntropyLoss, asynchronous=False, callback=None):
+def train(model, train_data, val_data="", batch_size=32, epochs=1, optim=optim.SGD(), loss=loss.SparseCrossEntropyLoss, asynchronous=False, callback=None, **kwargs):
     """Perform a train using a model. Default behaviour is synchronous.
 
         :param model: Model used to predict
@@ -70,7 +70,7 @@ def train(model, train_data, val_data, batch_size=32, epochs=1, optim=optim.SGD(
         :param callback: runs a callback function on results (asynchronous)
         :type callback: function
     """
-    return core.train(model, train_data, val_data, batch_size, epochs, optim, loss, asynchronous, callback)
+    return core.train(model, train_data, val_data, batch_size, epochs, optim, loss, asynchronous, callback, **kwargs)
 
 
 def export(model, path="."):
